""" Fichier brinscomp.py """

from Bio import SeqIO
from Bio.Seq import Seq


def brins_comp(seq="?", nom_fic=""):

    """ brins_comp() affiche les séquences complémentaires
        et inverses d'un brin d'ADN """

    # gestion des paramètres :
    #  si seq n'est pas "?", c'est la séquence à analyser
    #  si nom_fic est non vide, on y lit la séquence

    if seq == "?":
        print('aucune séquence ou séquence vide fournie. STOP.')
        return

    if nom_fic == "":
        print("séquences :")
        seq1 = Seq(seq)
    else:
        with open(nom_fic, encoding='UTF-8') as fic_seq:
            seq1 = SeqIO.read(fic_seq, 'fasta').seq
            print("séquences issues du fichier " + nom_fic)

    seq2 = seq1[::-1]        # calculs et transformations
    seq3 = seq1.complement()
    seq4 = seq3.reverse_complement()

    # affichages

    print("  originale              : ", seq1)
    print("  originale inverse      : ", seq2)
    print("  complémentaire         : ", seq3)
    print("  complémentaire inverse : ", seq4)


if __name__ == "__main__":  # auto-test

    print("-- test pour la chaine vide")
    brins_comp()

    print("-- test pour la chaine GATTACA")
    brins_comp("GATTACA")

    print("-- test pour le fichier 2765658.fasta (présent)")
    brins_comp("", "2765658.fasta")

# fin de l'auto-test
