""" Fichier contacts_utils.py """

import numpy as np
import matplotlib.pyplot as plt
import pylab


def dist_carbones_alpha(chaine_un, chaine_deux):

    """ distance entre deux carbones alpha """

    res1 = chaine_un['ATOM' and 'CA']
    res2 = chaine_deux['ATOM' and 'CA']
    vecteur_diff = res1 - res2
    la_dist = np.sqrt(np.sum(vecteur_diff * vecteur_diff))

    return la_dist


def matrice_distances(chaine_un, chaine_deux):

    """ Matrice des distances pour tous les carbones alpha
        des deux chaines chaineUn et chaineDeux            """

    matrice = np.zeros((len(chaine_un), len(chaine_deux)), float)
    for ligne, ch_un in enumerate(chaine_un):
        for colonne, ch_deux in enumerate(chaine_deux):
            matrice[ligne, colonne] =  \
              dist_carbones_alpha(ch_un, ch_deux)

    return matrice


def calcul_distances(modele, ch1, ch2):

    """ Calcul de toutes les distances """

    distances = matrice_distances(modele[ch1], modele[ch2])
    print("Distances entre les carbones alpha des chaines",
                                         ch1, "et", ch2, ":")
    print(F"minimum = {np.min(distances):7.2f} ; ", end="")
    print(F"maximum = {np.max(distances):7.2f} ")
    print("Taille de la matrice des distances : ", end="")
    print(F"{distances.shape}")

    return distances


def graphique_distances(id_pdb, ch1, ch2, distances):

    """ Carte des contacts issue des distances """

    # préparation du nom du graphique

    nom_gr = id_pdb + "-" + ch1 + "-" + ch2 + ".png"

    # production et sauvegarde du graphique

    pylab.matshow(distances)
    pylab.colorbar()
    plt.xlabel("chaine "+ch1)
    plt.ylabel("chaine "+ch2)

    # sauvegarde du graphique

    plt.savefig('./'+nom_gr, dpi=300, format='png')
