""" Fichier familprotnbf.py """

import os
import gzip
import re
import wget


def profil_famil(nom_famille=""):

    """ profil d'une famille de protéines via son nom PFAM """

    # cas 1 : paramètre vide ou absent

    if nom_famille == "":
        print("Aucun nom de famille fourni.")
        print("Essayer par exemple EF-hand_1")
        print("   ou Histone ou 14-3-3 ou Na_K-ATPase ou 7tm_1")
        return()

    # téléchargement du fichier des familles

    nom_dat = "Pfam-A.hmm.dat.gz"
    if os.path.isfile(nom_dat):
        os.remove(nom_dat)
    pfam_url = "https://ftp.ebi.ac.uk/pub/databases/Pfam/"
    pfam_url += "current_release/" + nom_dat
    with gzip.open(wget.download(pfam_url, bar=None), 'r') as fic:
        file_content = fic.read()
    ligs = str(file_content, 'UTF-8').split("\n")

    # parcours et découpage en identifiant/numéro

    lst_fam = {}
    fam_id = ""
    fam_pf = ""
    re_pf = r" (?P<pfnum>PF[0-9]+?)\."
    for lig in ligs:
        if lig[0:7] == '#=GF ID':
            fam_id = lig[8:].lstrip()
        if lig[0:7] == '#=GF AC':
            fam_pf = re.search(re_pf, lig).group('pfnum')
        if lig == '# STOCKHOLM 1.0':
            if fam_id != "":
                lst_fam[fam_id] = fam_pf
                fam_id = ""
                fam_pf = ""

    # ajout éventuel de la dernière famille

    if fam_id != "":
        lst_fam[fam_id] = fam_pf

    print(F"{len(lst_fam)}  familles vues dans {nom_dat}")

    # cas 2 : le paramètre n'est associé à aucun numéro de famille

    if nom_famille not in lst_fam:
        print("aucun identifiant de profil associé à " + nom_famille)
        return()

    # cas 3 : affichage du profil associé au paramètre

    num_pf = lst_fam[nom_famille]

    print("Numéro PFAM associé au nom de famille " +
           nom_famille + " et informations correspondantes :")
    print("   " + num_pf)
    hmm_url = num_pf+"?annotation=hmm"
    hmm_fichier = num_pf+".hmm.gz"
    url_family = "https://www.ebi.ac.uk/interpro/"
    url_family += "wwwapi//entry/pfam/"+hmm_url
    os.rename(wget.download(url_family, bar=None), hmm_fichier)
    with gzip.open(hmm_fichier, 'r') as fic:
        print(fic.read().decode())
    return()


if __name__ == "__main__":  # auto-test

    print("Profil HMM d'une famille de protéines")
    print("========================================")
    print()

    print("1. Appel de la fonction sans parametre")
    print("---------------------------------")
    profil_famil()
    print()

    IDPROF1 = "EF-hand"  # identifiant insuffisant
    print("2. Matrice de distances pour le profil ", IDPROF1)
    print("---------------------------------")
    profil_famil(IDPROF1)
    print()

    IDPROF2 = "EF-hand_1"  # identifiant OK
    print("3. Matrice de distances pour le profil ", IDPROF2)
    print("---------------------------------")
    profil_famil(IDPROF2)
    print()

# fin de l'auto-test
