""" Fichier homologues.py """

import os
from homologues_utils import lecture_fasta, \
     fasta_from_entrez, xml_from_blastp, parcours_xml


def rch_homologues(num_acc, motif_pr, nb_hom=5,
                                   overwrite_xml=False):

    """ protéines homologues via PHI-BLAST """

    print(F"Recherche via PHI-BLAST d'au plus {nb_hom} ", end="")
    print(F"protéines homologues à la protéine {num_acc} ")
    print(F"pour le motif {motif_pr}.\n")

    nom_fic_fasta = num_acc + ".fasta"
    nom_fic_xml = num_acc + ".xml"

    # si le fichier fasta existe déjà, on le lit
    # sinon on l'écrit aprés avoir été cherché la séquence
    # et l'identifiant au NCBI

    if os.path.isfile(nom_fic_fasta):
        fasta_rec = lecture_fasta(nom_fic_fasta)

    else:  # fasta_from_entrez
        fasta_rec = fasta_from_entrez(num_acc, nom_fic_fasta)

    # si le paramètre overwrite est mis à vrai et si le
    # le fichier XML des résultats de  PHI-BLAST existe,
    # on l'efface

    if overwrite_xml:
        if os.path.isfile(nom_fic_xml):
            os.remove(nom_fic_xml)
            print(F"  - suppression du fichier {nom_fic_xml}.")

    # si ce fichier XML des résultats n'existe pas,
    # on exécute PHI-BLAST avec les bons paramètres
    # pour le produire

    if not os.path.isfile(nom_fic_xml):
        xml_from_blastp(fasta_rec, motif_pr, nb_hom, nom_fic_xml)

    # on parcourt ensuite le fichier XML des résultats
    # pour construire le tableau des résultats recherchés

    tab_res = parcours_xml(nom_fic_xml, nb_hom)

    # on affiche ensuite les résultats

    print("Résultats :")
    if len(tab_res) == 0:
        print("   aucune protéine homologue ne semble trouvée.")
        return
    num_lig = 0
    for lig_res in tab_res:
        num_lig += 1
        if num_lig == 1:
            print("Numéro Prot_id          E-value      E-score")
        print(F"{num_lig:4}", end="   ")
        print(F"{lig_res['idprot']:<15}", end=" ")
        print(F"{lig_res['evalue']:12}", end=" ")
        print(F"{int(lig_res['escore']):5}")


if __name__ == "__main__":  # auto-test

    MOTIF = "G-C-x(1,3)-C-P-x(8,10)-C-C-x(2)-[PDEN]"
    rch_homologues("2NBT_A", MOTIF, 10)
    rch_homologues("2NBT_A", MOTIF,  5, False)
    rch_homologues("2NBT_A", MOTIF, 15, overwrite_xml=True)

# fin de l'auto-test
