""" Fichier profilhyd.py """

import re
from profilhyd_utils import sequence_fichier, sequence_uniprot


def profil_hydro(fic_ou_uniprot, taille):

    """ profil d'hydrophocité d'une proteine
        au format FASTA en local ou sur Uniprot """

    print("Profil d'hydrophobicité, protéine ",
          fic_ou_uniprot + " fenêtre taille " + str(taille))

    # si le paramètre fic_ou_uniprot finit par "fasta",
    # c'est un fichier local ;
    # sinon, c'est un identifiant pour Uniprot

    if re.search("fasta$", fic_ou_uniprot):
        sequence = sequence_fichier(fic_ou_uniprot)
    else:
        sequence = sequence_uniprot(fic_ou_uniprot)

    nb_res = len(sequence)

    if nb_res <= 0:
        print("La séquence associée à la protéine ",
          F"{fic_ou_uniprot} est vide. STOP.")
        return

    # valeurs de Kyte et Doolittle

    valeurs_kd = {'A': 1.8, 'C': 2.5, 'D': -3.5,
        'E': -3.5, 'F': 2.8, 'G': -0.4, 'H': -3.2, 'I': 4.5,
        'K': -3.9, 'L': 3.8, 'M': 1.9, 'N': -3.5, 'P': -1.6,
        'Q': -3.5, 'R': -4.5, 'S': -0.8, 'T': -0.7, 'V': 4.2,
        'W': -0.9, 'Y': -1.3}

    # transfert des valeurs d'hydrophobicité

    valeurs = []
    for residu in sequence:
        valeurs.append(valeurs_kd[residu])

    # calcul de l'hydrophobicité moyenne par fenêtre

    nbr = int((taille-1)/2)  # demi-largeur de la fenêtre
    hydrophobicite = []
    bornes = [0, 0]

    for i in range(nbr, nb_res-nbr):
        bornes[0] = int(i - nbr)
        bornes[1] = int(i + nbr + 1)
        moy_hydro = sum(valeurs[bornes[0]: bornes[1]]) / taille
        hydrophobicite.append(moy_hydro)

    if nb_res <= 8:
        print(hydrophobicite)
    else:
        print(hydrophobicite[:6])


if __name__ == "__main__":   # auto-test

    profil_hydro("BABG.fasta", 7)      # fichier non vu
    profil_hydro("P12345678", 7)       # URL non vue
    profil_hydro("IVLFCMAG.fasta", 7)  # fichier présent
    profil_hydro("P11229", 21)         # URL vue

# fin de l'auto-test
