""" Fichier rchbiblio.py  """

from Bio import Entrez


def recherche_biblio(mots_cle, nb_art=10):

    """ recherche d'articles avec la fonction esearch de Eutils,
        moteur de recherche Entrez du NCBI. """

    # Le NCBI exige une adresse e-mail

    Entrez.email = 'myAdress.mail@mydomain.com'

    # envoi de la recherche avec les bons paramètres
    # et récupération des résultats

    prm_recherche = Entrez.esearch(db='pubmed', retmax='30',
        datetype='PDAT', reldate=365, retmode='xml', term=mots_cle)
    resultats = Entrez.read(prm_recherche)
    nb_articles = int(resultats.get('Count'))

    # on quitte si aucun résultat

    if nb_articles == 0:
        print("aucun article sur PubMed pour ", mots_cle)
        return

    # affichage de la liste des indentifiants des articles

    liste_identifiants = resultats.get('IdList')
    print("Liste partielle des identifiants PMID :",
           liste_identifiants[:nb_art])
    print("Les ", min(nb_art, nb_articles), end='')
    print(" derniers articles en date")

    # rapatriement  et affichage des articles

    for pm_id in liste_identifiants[:nb_art]:
        information = Entrez.esummary(db='pubmed', id=pm_id,
           retmax='1', datetype='PDAT', reldate=365, retmode='xml')
        struc_article = Entrez.parse(information)
        for article in struc_article:
            print(" Date             :", (article['PubDate']))
            print(" Identifiant PMID :", pm_id)
            print(" Titre            :", (article['Title']))
            print(" Auteurs          :", (article['AuthorList']))
            print()


if __name__ == "__main__":   # auto-test

    print("Recherche biblio pour doner-schitzer")
    print("------------------------------------")
    recherche_biblio("donner-blitzen")
    print()

    MOTCLE = "spike sars"
    print("Recherche biblio pour ", MOTCLE)
    print("---------------------------------")
    print()
    recherche_biblio(MOTCLE, 5)

# fin de l'auto-test
