""" Fichier rchmotif.py """

import re
import os
from Bio import SeqIO


def rch_motif(fic="", reg_exp=""):

    """ recherche de motifs dans des séquences Fasta  """

    if fic == "":
        print("syntaxe : rch_motif(fichier,expressionRegulière)")
        return

    if not os.path.isfile(fic):
        print(" fichier " + fic + " non vu")
        return

    expr = re.compile(reg_exp, re.IGNORECASE)
    records = list(SeqIO.parse(fic, "fasta"))
    print(F"sur les {len(records)} séquences du fichier {fic}")

    ind_seq = -1
    seqm = []
    for seqc in records:
        ind_seq += 1
        laseq = seqc.seq
        if expr.match(str(laseq)):
            seqm.append(ind_seq)
    print(F"{len(seqm)} séquences correspondent à {reg_exp} :")

    for indq in seqm:
        id_seq = records[indq].id
        print(F"  séquence {(1+indq):2d} id = { id_seq } ")


if __name__ == "__main__":  # auto-test

    rch_motif("")
    rch_motif("non", "^MSQE")              # fichier non vu
    rch_motif("proteines.fasta", "^MSQE")  # fichier présent

# fin de l'auto-test
