""" Fichier structure_pdb.py """

import os
import Bio.PDB
from Bio.PDB.PDBParser import PDBParser
from ramachandran_utils import ligne_titre


def structure_pdb(id_pdb="", ch1="", ch2=""):

    """ distances entre carbones alpha et carte des contacts
        de deux chaines polypeptidiques d'un fichier-structure
                                                     de la PDB """
    if id_pdb == "":
        print("syntaxe : contacts(id_pdb,chaine1,chaine2) ")
        return None

    pdbl = Bio.PDB.PDBList()
    pdbl.retrieve_pdb_file(id_pdb, pdir=".", file_format="pdb",
                                               overwrite=False)
    fichier = "pdb"+id_pdb.lower()+".ent"

    # test de la présence du fichier

    if not os.path.isfile(fichier):
        print("aucun fichier PDB avec l'id "+id_pdb+" vu ")
        return None

    nbl_titre = ligne_titre(fichier)

    # récupération des chaines polypeptidiques

    decoupage = PDBParser()
    structure = decoupage.get_structure('codePDB', fichier)
    modele = structure[0]
    lst_chaines = modele.child_dict
    nb_chaines = len(lst_chaines)

    print(F"-- Protéine {fichier} : {nbl_titre[0]} lignes")
    print(F" {nbl_titre[1]}")
    print(F" {nb_chaines} chaines polypeptidiques")

    for lettre in lst_chaines.keys():
        print(lettre+" ", end="")
    print()

    if ch1 == "" or ch2 == "":
        print("aucune lettre de chaine fournie, stop.")
        return None

    if ch1 not in lst_chaines:
        print("chaine ", ch1, " non vue, stop.")
        return None

    if ch2 not in lst_chaines:
        print("chaine ", ch2, " non vue, stop.")
        return None

    return structure
