""" Fichier superp_pdb.py """

import os
import Bio.PDB
from Bio.PDB.PDBParser import PDBParser
from ramachandran_utils import ligne_titre


def atomes_region_aa(chaine, region):

    """ atomes de carbone alpha dans la séquence comparée """

    atomes = []
    for residu in chaine:
        if residu.get_id()[1] in region:
            if residu.has_id('CA'):
                atomes.append(residu['CA'])
    return atomes


def lecture_ca_pdb(id_pdb=""):

    """ lecture d'un fichier PDB et atomes de carbone alpha """

    if id_pdb == "":
        print("aucun nom de structure fourni")
        print("syntaxe : lecture_ca_pdb(id_PDB)")
        return [1, []]

    pdbl = Bio.PDB.PDBList()

    pdbl.retrieve_pdb_file(id_pdb, pdir=".",
           file_format="pdb", overwrite=False)
    fichier = "pdb"+id_pdb.lower()+".ent"

    # test de la présence du fichier

    if not os.path.isfile(fichier):
        print("aucun fichier PDB avec l'id "+id_pdb+" vu ")
        return [1, []]

    titre = ligne_titre(fichier)
    print(F"-- Protéine {fichier} : {titre[1]}")

    decoupage = PDBParser()
    structure = decoupage.get_structure('codePDB', fichier)
    premier_modele = structure[0]
    chaine = premier_modele["A"]

    atomes_ca = []
    for residu in chaine:
        if residu.has_id('CA'):
            atomes_ca.append(residu['CA'])

    print(F" avec {len(atomes_ca)} atomes CA")
    return [0, chaine]


if __name__ == "__main__":  # auto-test

    lecture_ca_pdb()         # rappel de la syntaxe
    lecture_ca_pdb("AAAA")   # structure inexistante
    lecture_ca_pdb("1UBQ")   # structure existante

# fin de l'auto-test
